@@ -62,7 +62,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.7',
+        'version': '2.0.8',
         'name': 'IPCMB feature selector',
         'keywords': 'rpi primitives',
         'source': {
@@ -88,8 +88,8 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: Dict[str, str] = None) -> None:
-        super().__init__(hyperparams=hyperparams, random_seed=random_seed)
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+        super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self.is_feature_selection = True
         self.index = None
         self.training_inputs = None
